==> v4l-utils-1.26.1-1-aarch64.pkg.tar.xz: usr/share/doc/v4l-utils/html/group__frontend.js <==
var group__frontend =
[
    [ "dvb-fe.h", "dvb-fe_8h.html", null ],
    [ "dvb-v5-std.h", "dvb-v5-std_8h.html", null ],
    [ "dvb_v5_fe_parms", "structdvb__v5__fe__parms.html", [
      [ "abort", "structdvb__v5__fe__parms.html#a189e9ea2b61c593ec9f001b0a6925b89", null ],
      [ "current_sys", "structdvb__v5__fe__parms.html#af528ac7420efd3b29f4dfa456ee791ea", null ],
      [ "default_charset", "structdvb__v5__fe__parms.html#a95f6ff7f8d5c56d33c2683348d921cbf", null ],
      [ "diseqc_wait", "structdvb__v5__fe__parms.html#a7904d056b88d48c39c8fef242b963539", null ],
      [ "freq_bpf", "structdvb__v5__fe__parms.html#a304dc4d27ecfea9095ce292c8af7ae8a", null ],
      [ "has_v5_stats", "structdvb__v5__fe__parms.html#a4236b34fbde5c0bb52ea340b52c7cdae", null ],
      [ "info", "structdvb__v5__fe__parms.html#ab5999cab0a0706572eb2e4dc0d9ec939", null ],
      [ "legacy_fe", "structdvb__v5__fe__parms.html#a0c45cac03a5531547470501f75627edf", null ],
      [ "lna", "structdvb__v5__fe__parms.html#a0a61f74a8d249a678e23068d92c28759", null ],
      [ "lnb", "structdvb__v5__fe__parms.html#ad9d556f33c37541df2b6277edd5ef9ab", null ],
      [ "logfunc", "structdvb__v5__fe__parms.html#ad2bb3ac5cfd12c88a216ce686ed32249", null ],
      [ "num_systems", "structdvb__v5__fe__parms.html#a7bfb07317e3f68ec8a5a4d4930427517", null ],
      [ "output_charset", "structdvb__v5__fe__parms.html#ac9e9f5257d54e6a9e4958282c716d77f", null ],
      [ "sat_number", "structdvb__v5__fe__parms.html#a96c8ea5eb5ae3a69671af245efab7dd9", null ],
      [ "systems", "structdvb__v5__fe__parms.html#acddda034e583c9563bfc02a7289c26c1", null ],
      [ "verbose", "structdvb__v5__fe__parms.html#a907df1b9fd524cfb0d99ed9e50ccf799", null ],
      [ "version", "structdvb__v5__fe__parms.html#ae17515452599996f08a0d8c8f85c5439", null ]
    ] ],
    [ "DTV_AUDIO_PID", "group__frontend.html#gaebb50fd66fd7824083f8a2c85e3eeba7", null ],
    [ "DTV_BER", "group__frontend.html#ga0a380404fc053ab72d8093a5acf60103", null ],
    [ "DTV_CH_NAME", "group__frontend.html#ga8e5ad40f65a7d620a32f182ffe39343f", null ],
    [ "DTV_COUNTRY_CODE", "group__frontend.html#ga2f32e16029dac63adb27066ca31092be", null ],
    [ "DTV_DISEQC_LNB", "group__frontend.html#gab83f42ae393f28d7a754e725fcab24f5", null ],
    [ "DTV_DISEQC_WAIT", "group__frontend.html#gab5416ba1e50dbae4920c45e02b7ca6e4", null ],
    [ "DTV_FREQ_BPF", "group__frontend.html#ga2f9ef2d7c18bb0d41cbda6bb7e076068", null ],
    [ "DTV_MAX_STAT_COMMAND", "group__frontend.html#gaddcdfb1573e0df65fafbab05f5470b45", null ],
    [ "DTV_MAX_USER_COMMAND", "group__frontend.html#ga87869ca15832145f9bd6b94c30fdd3aa", null ],
    [ "DTV_NUM_KERNEL_STATS", "group__frontend.html#gafce01ede7943ede2215a1fc8f4e90bf2", null ],
    [ "DTV_NUM_STATS_PROPS", "group__frontend.html#ga13252e390ff0550e0bff827523dc33bd", null ],
    [ "DTV_PER", "group__frontend.html#gaae80c2c97096e7cfbf5a8c2de5eb5001", null ],
    [ "DTV_PLS_CODE", "group__frontend.html#ga58dcf75eb5cb6ccbb71c56b0c55386ed", null ],
    [ "DTV_PLS_MODE", "group__frontend.html#ga5e889b20ef56ee37df277047f7553135", null ],
    [ "DTV_POLARIZATION", "group__frontend.html#gab68f6a50e08763b54317cd234b625afc", null ],
    [ "DTV_PRE_BER", "group__frontend.html#gade8a86029dae354c98ce75825fff8f37", null ],
    [ "DTV_QUALITY", "group__frontend.html#gaa73136f5485832d7094d3cad6885798c", null ],
    [ "DTV_SAT_NUMBER", "group__frontend.html#gadc69806e6e6365c85dba8b6aabbe1eb2", null ],
    [ "DTV_SERVICE_ID", "group__frontend.html#gab5829fcdd1b0d8d4da9aed19be6efe46", null ],
    [ "DTV_STAT_COMMAND_START", "group__frontend.html#ga12e411fb91f605a8138edca11a1a8408", null ],
    [ "DTV_STAT_NAME_SIZE", "group__frontend.html#gab3a5fd4cad7c84e6ef44166fe4d69dfd", null ],
    [ "DTV_STATUS", "group__frontend.html#ga6b9d1ac1e7f098f2e189408c573957a1", null ],
    [ "DTV_USER_COMMAND_START", "group__frontend.html#gaac44db37fdcadc57f7b13b7756486923", null ],
    [ "DTV_USER_NAME_SIZE", "group__frontend.html#ga6305be8c010db11ab223b947d7f3e50e", null ],
    [ "DTV_VCHANNEL", "group__frontend.html#gaa80dac4eb7eff45f4cbf90e61b168a9f", null ],
    [ "DTV_VIDEO_PID", "group__frontend.html#gaa83750f7305090c419784e78d6275c49", null ],
    [ "MAX_DELIVERY_SYSTEMS", "group__frontend.html#ga9365465bdfe223728b52987ee44cdb7e", null ],
    [ "dvb_add_parms_for_sys", "group__frontend.html#ga23213ad4b8bd3e5e51fdbd534d8b04d4", null ],
    [ "dvb_attr_names", "group__frontend.html#ga493bc144f8954dd4bc183a4a648dc641", null ],
    [ "dvb_cmd_name", "group__frontend.html#gaa132cab088e3e9944267e3121a77b7b5", null ],
    [ "dvb_fe_close", "group__frontend.html#gaa245d22bee224c452b0acbb718e70acf", null ],
    [ "dvb_fe_diseqc_burst", "group__frontend.html#gac8cccd0e6133244f0e929179bf355089", null ],
    [ "dvb_fe_diseqc_cmd", "group__frontend.html#gaf18d4dd1c36a0f7dc543a48866d76002", null ],
    [ "dvb_fe_diseqc_reply", "group__frontend.html#ga7caacdc6d03ba6469155e916a5ea4555", null ],
    [ "dvb_fe_dummy", "group__frontend.html#ga483343825ef718af4699c80cc8e715c2", null ],
    [ "dvb_fe_get_event", "group__frontend.html#ga9f612d43d2a2ee58727e24b4bb732615", null ],
    [ "dvb_fe_get_parms", "group__frontend.html#ga5c19c7743b1bb9acd5d7cba86b275b88", null ],
    [ "dvb_fe_get_stats", "group__frontend.html#gafb6b35003768d938a4e1623d9fb82baa", null ],
    [ "dvb_fe_is_satellite", "group__frontend.html#ga09238567b68ba0225b6ed97934e0cb8a", null ],
    [ "dvb_fe_lnb_high_voltage", "group__frontend.html#ga5e56fddceae665652d14ce360a844f47", null ],
    [ "dvb_fe_open", "group__frontend.html#ga80a28cfd7897a5c4c4033fbfb05a469d", null ],
    [ "dvb_fe_open2", "group__frontend.html#ga98947ae8543a272d46bbdf26bd008bc9", null ],
    [ "dvb_fe_open_flags", "group__frontend.html#gae0a589f16c0c28d1f187e7c6fbcce7f8", null ],
    [ "dvb_fe_prt_parms", "group__frontend.html#gad4004fd14c39191e532fb1bc2431946c", null ],
    [ "dvb_fe_retrieve_ber", "group__frontend.html#ga45f6b2b5b027bc6731be41f5bdb426af", null ],
    [ "dvb_fe_retrieve_parm", "group__frontend.html#ga7fc5188032e1f4d15750b877924d1690", null ],
    [ "dvb_fe_retrieve_per", "group__frontend.html#ga645124ce5fdacee64226cbae20e24b48", null ],
    [ "dvb_fe_retrieve_quality", "group__frontend.html#ga968cca91f370fdd3942786b9f4db634e", null ],
    [ "dvb_fe_retrieve_stats", "group__frontend.html#ga3ad32e6b435b72a08154c9de86368b1e", null ],
    [ "dvb_fe_retrieve_stats_layer", "group__frontend.html#gaad807c2e5f72ff70ba3ca66e80a5bfca", null ],
    [ "dvb_fe_sec_tone", "group__frontend.html#ga8b06b8bfbd2f5a9df82b610b5f3acbb9", null ],
    [ "dvb_fe_sec_voltage", "group__frontend.html#ga6c23a189df99b721a08593f92b9f5d8c", null ],
    [ "dvb_fe_set_default_country", "group__frontend.html#ga06b0458138f4633cee4c02097bda531a", null ],
    [ "dvb_fe_set_parms", "group__frontend.html#gabde1041d5e55c41665da29bb121daf8a", null ],
    [ "dvb_fe_snprintf_eng", "group__frontend.html#ga56400b4982a38c989788970c4da51acc", null ],
    [ "dvb_fe_snprintf_stat", "group__frontend.html#ga5537a2ab838f8814c5d22d90c648b3d5", null ],
    [ "dvb_fe_store_parm", "group__frontend.html#ga419ad7168a9f884346d74c997e1141b3", null ],
    [ "dvb_set_compat_delivery_system", "group__frontend.html#ga5db3cc6a449e8a532ac07f0d198d7217", null ],
    [ "dvb_set_sys", "group__frontend.html#gaa81228d801afc6d5c293e4deb7b60e50", null ]
];

==> v4l-utils-1.30.1-1-aarch64.pkg.tar.xz: usr/share/doc/v4l-utils/html/group__frontend.js <==
var group__frontend =
[
    [ "dvb-fe.h", "dvb-fe_8h.html", null ],
    [ "dvb-v5-std.h", "dvb-v5-std_8h.html", null ],
    [ "dvb_v5_fe_parms", "structdvb__v5__fe__parms.html", [
      [ "abort", "structdvb__v5__fe__parms.html#a189e9ea2b61c593ec9f001b0a6925b89", null ],
      [ "current_sys", "structdvb__v5__fe__parms.html#af528ac7420efd3b29f4dfa456ee791ea", null ],
      [ "default_charset", "structdvb__v5__fe__parms.html#a95f6ff7f8d5c56d33c2683348d921cbf", null ],
      [ "diseqc_wait", "structdvb__v5__fe__parms.html#a7904d056b88d48c39c8fef242b963539", null ],
      [ "freq_bpf", "structdvb__v5__fe__parms.html#a304dc4d27ecfea9095ce292c8af7ae8a", null ],
      [ "has_v5_stats", "structdvb__v5__fe__parms.html#a4236b34fbde5c0bb52ea340b52c7cdae", null ],
      [ "info", "structdvb__v5__fe__parms.html#ab5999cab0a0706572eb2e4dc0d9ec939", null ],
      [ "legacy_fe", "structdvb__v5__fe__parms.html#a0c45cac03a5531547470501f75627edf", null ],
      [ "lna", "structdvb__v5__fe__parms.html#a0a61f74a8d249a678e23068d92c28759", null ],
      [ "lnb", "structdvb__v5__fe__parms.html#ad9d556f33c37541df2b6277edd5ef9ab", null ],
      [ "logfunc", "structdvb__v5__fe__parms.html#ad2bb3ac5cfd12c88a216ce686ed32249", null ],
      [ "num_systems", "structdvb__v5__fe__parms.html#a7bfb07317e3f68ec8a5a4d4930427517", null ],
      [ "output_charset", "structdvb__v5__fe__parms.html#ac9e9f5257d54e6a9e4958282c716d77f", null ],
      [ "sat_number", "structdvb__v5__fe__parms.html#a96c8ea5eb5ae3a69671af245efab7dd9", null ],
      [ "systems", "structdvb__v5__fe__parms.html#acddda034e583c9563bfc02a7289c26c1", null ],
      [ "verbose", "structdvb__v5__fe__parms.html#a907df1b9fd524cfb0d99ed9e50ccf799", null ],
      [ "version", "structdvb__v5__fe__parms.html#ae17515452599996f08a0d8c8f85c5439", null ]
    ] ],
    [ "DTV_AUDIO_PID", "group__frontend.html#gaebb50fd66fd7824083f8a2c85e3eeba7", null ],
    [ "DTV_BER", "group__frontend.html#ga0a380404fc053ab72d8093a5acf60103", null ],
    [ "DTV_CH_NAME", "group__frontend.html#ga8e5ad40f65a7d620a32f182ffe39343f", null ],
    [ "DTV_COUNTRY_CODE", "group__frontend.html#ga2f32e16029dac63adb27066ca31092be", null ],
    [ "DTV_DISEQC_LNB", "group__frontend.html#gab83f42ae393f28d7a754e725fcab24f5", null ],
    [ "DTV_DISEQC_WAIT", "group__frontend.html#gab5416ba1e50dbae4920c45e02b7ca6e4", null ],
    [ "DTV_FREQ_BPF", "group__frontend.html#ga2f9ef2d7c18bb0d41cbda6bb7e076068", null ],
    [ "DTV_MAX_STAT_COMMAND", "group__frontend.html#gaddcdfb1573e0df65fafbab05f5470b45", null ],
    [ "DTV_MAX_USER_COMMAND", "group__frontend.html#ga87869ca15832145f9bd6b94c30fdd3aa", null ],
    [ "DTV_NUM_KERNEL_STATS", "group__frontend.html#gafce01ede7943ede2215a1fc8f4e90bf2", null ],
    [ "DTV_NUM_STATS_PROPS", "group__frontend.html#ga13252e390ff0550e0bff827523dc33bd", null ],
    [ "DTV_PER", "group__frontend.html#gaae80c2c97096e7cfbf5a8c2de5eb5001", null ],
    [ "DTV_PLS_CODE", "group__frontend.html#ga58dcf75eb5cb6ccbb71c56b0c55386ed", null ],
    [ "DTV_PLS_MODE", "group__frontend.html#ga5e889b20ef56ee37df277047f7553135", null ],
    [ "DTV_POLARIZATION", "group__frontend.html#gab68f6a50e08763b54317cd234b625afc", null ],
    [ "DTV_PRE_BER", "group__frontend.html#gade8a86029dae354c98ce75825fff8f37", null ],
    [ "DTV_QUALITY", "group__frontend.html#gaa73136f5485832d7094d3cad6885798c", null ],
    [ "DTV_SAT_NUMBER", "group__frontend.html#gadc69806e6e6365c85dba8b6aabbe1eb2", null ],
    [ "DTV_SERVICE_ID", "group__frontend.html#gab5829fcdd1b0d8d4da9aed19be6efe46", null ],
    [ "DTV_STAT_COMMAND_START", "group__frontend.html#ga12e411fb91f605a8138edca11a1a8408", null ],
    [ "DTV_STAT_NAME_SIZE", "group__frontend.html#gab3a5fd4cad7c84e6ef44166fe4d69dfd", null ],
    [ "DTV_STATUS", "group__frontend.html#ga6b9d1ac1e7f098f2e189408c573957a1", null ],
    [ "DTV_USER_COMMAND_START", "group__frontend.html#gaac44db37fdcadc57f7b13b7756486923", null ],
    [ "DTV_USER_NAME_SIZE", "group__frontend.html#ga6305be8c010db11ab223b947d7f3e50e", null ],
    [ "DTV_VCHANNEL", "group__frontend.html#gaa80dac4eb7eff45f4cbf90e61b168a9f", null ],
    [ "DTV_VIDEO_PID", "group__frontend.html#gaa83750f7305090c419784e78d6275c49", null ],
    [ "MAX_DELIVERY_SYSTEMS", "group__frontend.html#ga9365465bdfe223728b52987ee44cdb7e", null ],
    [ "dvb_quality", "group__frontend.html#ga7eccef04635a4b32d251e0fa9fe43a97", [
      [ "DVB_QUAL_UNKNOWN", "dvb-v5-std_8h.html#ga7eccef04635a4b32d251e0fa9fe43a97a5d7dac7c1ae946e063e4674c41ff499c", null ],
      [ "DVB_QUAL_POOR", "dvb-v5-std_8h.html#ga7eccef04635a4b32d251e0fa9fe43a97af370ea1484e641aad1edb197f8f92dc0", null ],
      [ "DVB_QUAL_OK", "dvb-v5-std_8h.html#ga7eccef04635a4b32d251e0fa9fe43a97ab019fe5c846dbad645b63788eda873ec", null ],
      [ "DVB_QUAL_GOOD", "dvb-v5-std_8h.html#ga7eccef04635a4b32d251e0fa9fe43a97a5118d9312ce9b60af3c4d53a91d11642", null ]
    ] ],
    [ "dvb_add_parms_for_sys", "group__frontend.html#ga23213ad4b8bd3e5e51fdbd534d8b04d4", null ],
    [ "dvb_attr_names", "group__frontend.html#ga493bc144f8954dd4bc183a4a648dc641", null ],
    [ "dvb_cmd_name", "group__frontend.html#gaa132cab088e3e9944267e3121a77b7b5", null ],
    [ "dvb_fe_close", "group__frontend.html#gaa245d22bee224c452b0acbb718e70acf", null ],
    [ "dvb_fe_diseqc_burst", "group__frontend.html#gac8cccd0e6133244f0e929179bf355089", null ],
    [ "dvb_fe_diseqc_cmd", "group__frontend.html#gaf18d4dd1c36a0f7dc543a48866d76002", null ],
    [ "dvb_fe_diseqc_reply", "group__frontend.html#ga7caacdc6d03ba6469155e916a5ea4555", null ],
    [ "dvb_fe_dummy", "group__frontend.html#ga483343825ef718af4699c80cc8e715c2", null ],
    [ "dvb_fe_get_event", "group__frontend.html#ga9f612d43d2a2ee58727e24b4bb732615", null ],
    [ "dvb_fe_get_parms", "group__frontend.html#ga5c19c7743b1bb9acd5d7cba86b275b88", null ],
    [ "dvb_fe_get_stats", "group__frontend.html#gafb6b35003768d938a4e1623d9fb82baa", null ],
    [ "dvb_fe_is_satellite", "group__frontend.html#ga09238567b68ba0225b6ed97934e0cb8a", null ],
    [ "dvb_fe_lnb_high_voltage", "group__frontend.html#ga5e56fddceae665652d14ce360a844f47", null ],
    [ "dvb_fe_open", "group__frontend.html#ga80a28cfd7897a5c4c4033fbfb05a469d", null ],
    [ "dvb_fe_open2", "group__frontend.html#ga98947ae8543a272d46bbdf26bd008bc9", null ],
    [ "dvb_fe_open_flags", "group__frontend.html#gae0a589f16c0c28d1f187e7c6fbcce7f8", null ],
    [ "dvb_fe_prt_parms", "group__frontend.html#gad4004fd14c39191e532fb1bc2431946c", null ],
    [ "dvb_fe_retrieve_ber", "group__frontend.html#ga45f6b2b5b027bc6731be41f5bdb426af", null ],
    [ "dvb_fe_retrieve_parm", "group__frontend.html#ga7fc5188032e1f4d15750b877924d1690", null ],
    [ "dvb_fe_retrieve_per", "group__frontend.html#ga645124ce5fdacee64226cbae20e24b48", null ],
    [ "dvb_fe_retrieve_quality", "group__frontend.html#ga968cca91f370fdd3942786b9f4db634e", null ],
    [ "dvb_fe_retrieve_stats", "group__frontend.html#ga3ad32e6b435b72a08154c9de86368b1e", null ],
    [ "dvb_fe_retrieve_stats_layer", "group__frontend.html#gaad807c2e5f72ff70ba3ca66e80a5bfca", null ],
    [ "dvb_fe_sec_tone", "group__frontend.html#ga8b06b8bfbd2f5a9df82b610b5f3acbb9", null ],
    [ "dvb_fe_sec_voltage", "group__frontend.html#ga6c23a189df99b721a08593f92b9f5d8c", null ],
    [ "dvb_fe_set_default_country", "group__frontend.html#ga06b0458138f4633cee4c02097bda531a", null ],
    [ "dvb_fe_set_parms", "group__frontend.html#gabde1041d5e55c41665da29bb121daf8a", null ],
    [ "dvb_fe_snprintf_eng", "group__frontend.html#ga56400b4982a38c989788970c4da51acc", null ],
    [ "dvb_fe_snprintf_stat", "group__frontend.html#ga5537a2ab838f8814c5d22d90c648b3d5", null ],
    [ "dvb_fe_store_parm", "group__frontend.html#ga419ad7168a9f884346d74c997e1141b3", null ],
    [ "dvb_set_compat_delivery_system", "group__frontend.html#ga5db3cc6a449e8a532ac07f0d198d7217", null ],
    [ "dvb_set_sys", "group__frontend.html#gaa81228d801afc6d5c293e4deb7b60e50", null ]
];
